==> 3.15.3.tar.gz: 3.15.3/source/app_home/tests/test_sirene_admin.py <==
# tests app_sirene

from django.test import TestCase, override_settings
from django.test import TransactionTestCase
from django.urls import reverse


from app_home.home import cavaliba_update
from app_home.models import CavalibaConfiguration

from app_user.models import SireneUser
from app_user.role import role_get_by_name




class AppSireneAdminTest(TestCase):

    def setUp(self):
        #print("setUp: Run once for every test method to setup clean data.")
        pass
    
    @classmethod
    def setUpTestData(cls):
        cavaliba_update(verbose=False)

        user = SireneUser.objects.create(login="unittest", firstname="unittestname")
        user.save()

        role = role_get_by_name("role_sirene_admin")
        role.users.add(user)
        role.save()



    @override_settings(CAVALIBA_AUTH_MODE="unittest")
    def test_public(self):
        response = self.client.get(reverse('app_sirene:index'))
        self.assertEqual(response.status_code, 200)

    @override_settings(CAVALIBA_AUTH_MODE="unittest")
    def test_anonymous(self):
        response = self.client.get(reverse('app_sirene:anonymous'))
        # user = admin
        self.assertEqual(response.status_code, 200)

    @override_settings(CAVALIBA_AUTH_MODE="unittest")
    def test_trusted_ip(self):
        conf = CavalibaConfiguration.objects.get(appname="user",keyname="TRUSTED_ANONYMOUS_IPS")
        conf.value="0.0.0.0/0"
        conf.save()

        response = self.client.get(reverse('app_sirene:anonymous'))
        self.assertEqual(response.status_code, 200)


    @override_settings(CAVALIBA_AUTH_MODE="unittest")
    def test_private_access(self):
        response = self.client.get(reverse('app_sirene:private'))
        self.assertEqual(response.status_code, 200)

==> 3.15.4.tar.gz: 3.15.4/source/app_home/tests/test_sirene_admin.py <==
# tests app_sirene

from django.test import TestCase, override_settings
from django.test import TransactionTestCase
from django.urls import reverse


import app_home.cache as cache
from app_home.models import CavalibaConfiguration

from app_user.models import SireneUser
from app_user.role import role_get_by_name


class AppSireneAdminTest(TestCase):

    fixtures = ["test"]

    def setUp(self):
        pass
        cache.init()

        user = SireneUser.objects.create(login="unittest", firstname="unittestname")
        user.save()

        role = role_get_by_name("role_sirene_admin")
        role.users.add(user)
        role.save()



    @override_settings(CAVALIBA_AUTH_MODE="unittest")
    def test_public(self):
        response = self.client.get(reverse('app_sirene:index'))
        self.assertEqual(response.status_code, 200)
        pass


    @override_settings(CAVALIBA_AUTH_MODE="unittest")
    def test_anonymous(self):
        response = self.client.get(reverse('app_sirene:anonymous'))
        # user = admin
        self.assertEqual(response.status_code, 200)

    @override_settings(CAVALIBA_AUTH_MODE="unittest")
    def test_trusted_ip(self):
        conf = CavalibaConfiguration.objects.get(appname="user",keyname="TRUSTED_ANONYMOUS_IPS")
        conf.value="0.0.0.0/0"
        conf.save()

        response = self.client.get(reverse('app_sirene:anonymous'))
        self.assertEqual(response.status_code, 200)


    @override_settings(CAVALIBA_AUTH_MODE="unittest")
    def test_private_access(self):
        response = self.client.get(reverse('app_sirene:private'))
        self.assertEqual(response.status_code, 200)
